Summary:        Reusable library for GPU-accelerated video/image rendering primitives
Name:           libplacebo
Version:        5.264.1
Release:        2%{?dist}
License:        LGPLv2+
URL:            https://github.com/haasn/libplacebo
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc gcc-c++ meson
BuildRequires:  python3-mako
BuildRequires:  libepoxy-devel libunwind-devel lcms2-devel
BuildRequires:  vulkan-devel glslang-devel libshaderc-devel
BuildRequires:  glad >= 2.0.0

%description
libplacebo is the core rendering algorithms and ideas of mpv rewritten as an independent library.
As of today, libplacebo contains a large assortment of video processing shaders, focusing on
both quality and performance. These include features such as the following:
1.High-quality, optimized upscaling and downscaling including support for polar filters ("Jinc"),
anti-aliasing, anti-ringing and gamma correct scaling.
2.Color management and format conversions for a wide variety of HDR or wide gamut color spaces.
This includes support for ICC profiles, ITU-R BT.1886 emulation, colorimetrically accurate clipping,
custom 1D/3D LUTs, scene-referred OOTFs (such as HLG), constant luminance formats including ICtCp and
a variety of film industry formats ranging from XYZ to Sony's S-Log or Panasonic's V-Gamut.
3.Tunable debanding shader. This is based on flash3kyuu, expanded to provide high quality
by combining multiple debanding passes.
4.Dynamic HDR tone mapping, including shaders for real-time peak and scene-change detection,
chroma-preserving (luma-only) tone mapping, highlight desaturation, dynamic exposure control and
a variety of industry-standard EETFs including BT.2390.
5.High performance film grain synthesis for AV1 and H.274, allowing media players to offload
this part of decoding from the CPU to the GPU.
6.A pluggable, extensible custom shader syntax, equivalent to an improved version of mpv's .hook syntax.
This can be used to arbitrarily extend the range of custom shaders to include popular user shaders like
RAVU, FSRCNNX, or Anime4K. See the mpv wiki on user scripts for more information.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The package contains libraries and header files for developing with %{name}.


%prep
%autosetup -p1 -n %{name}-%{version}


%build
%meson -Ddovi=disabled -Dlibdovi=disabled -Dd3d11=disabled -Ddemos=False
%meson_build


%install
%meson_install


%files
%license LICENSE
%doc README.md
%{_libdir}/libplacebo.so.264


%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libplacebo.pc


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.264.1-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 20 2023 rockerzhu <rockerzhu@tencent.com> - 5.264.1-1
- Initial build.
